EnableCanvas
========================================

.. currentmodule:: enaml.widgets.enable_canvas

.. autoclass:: EnableCanvas


Backends
--------

Qt
^^

.. inheritance-diagram::
    enaml.widgets.qt.qt_enable_canvas.QtEnableCanvas
    :parts: 1

.. autoclass:: enaml.widgets.qt.qt_enable_canvas.QtEnableCanvas

Wx
^^

.. inheritance-diagram::
    enaml.widgets.wx.wx_enable_canvas.WXEnableCanvas
    :parts: 1

.. autoclass:: enaml.widgets.wx.wx_enable_canvas.WXEnableCanvas
